@@ -43,7 +43,7 @@ static int two_node;
 static unsigned int disable_openais;
 static unsigned int portnum;
 static int num_nodenames;
-static char *key_filename;
+static char *key_filename=NULL;
 static char *mcast_name;
 static char *cluster_name;
 static char error_reason[1024] = { '\0' };
@@ -360,7 +360,8 @@ static int verify_nodename(struct objdb_iface_ver0 *objdb, char *nodename)
 
 		if (objdb_get_string(objdb, nodes_handle, "name", &str)) {
 			sprintf(error_reason, "Cannot get node name");
-			break;
+			nodes_handle = nodeslist_next(objdb, find_handle);
+			continue;
 		}
 
 		strcpy(nodename3, str);
@@ -494,7 +495,7 @@ static int get_env_overrides()
 
 static int get_nodename(struct objdb_iface_ver0 *objdb)
 {
-	char *nodeid_str;
+	char *nodeid_str = NULL;
 	unsigned int object_handle;
 	unsigned int find_handle;
 	unsigned int node_object_handle;
@@ -916,6 +917,74 @@ static int set_noccs_defaults(struct objdb_iface_ver0 *objdb)
 	return 0;
 }
 
+/* Move an object/key tree */
+static int copy_config_tree(struct objdb_iface_ver0 *objdb, unsigned int source_object, unsigned int target_parent_object, int always_create)
+{
+	unsigned int object_handle;
+	unsigned int new_object;
+	unsigned int find_handle;
+	char object_name[1024];
+	int object_name_len;
+	void *key_name;
+	int key_name_len;
+	void *key_value;
+	int key_value_len;
+	int res;
+
+	/* Create new parent object if necessary */
+	objdb->object_name_get(source_object, object_name, &object_name_len);
+
+	objdb->object_find_create(target_parent_object, object_name, strlen(object_name), &find_handle);
+	if (always_create || objdb->object_find_next(find_handle, &object_handle))
+			objdb->object_create(target_parent_object, &new_object, object_name, object_name_len);
+	objdb->object_find_destroy(find_handle);
+
+	/* Copy the keys */
+	objdb->object_key_iter_reset(new_object);
+
+	while (!objdb->object_key_iter(source_object, &key_name, &key_name_len,
+				       &key_value, &key_value_len)) {
+
+		objdb->object_key_create(new_object, key_name, key_name_len,
+					 key_value, key_value_len);
+	}
+
+	/* Create sub-objects */
+	res = objdb->object_find_create(source_object, NULL, 0, &find_handle);
+	if (res) {
+		sprintf(error_reason, "error resetting object iterator for object %d: %d\n", source_object, res);
+		return -1;
+	}
+
+	while ( (res = objdb->object_find_next(find_handle, &object_handle) == 0)) {
+
+		/* Down we go ... */
+		copy_config_tree(objdb, object_handle, new_object, 0);
+	}
+	objdb->object_find_destroy(find_handle);
+
+	return 0;
+}
+
+/*
+ * Copy trees from /cluster where they live in cluster.conf, into the root
+ * of the config tree where corosync expects to find them.
+ */
+static int copy_tree_to_root(struct objdb_iface_ver0 *objdb, char *name, int always_create)
+{
+	unsigned int find_handle;
+	unsigned int object_handle;
+	int res=0;
+
+	objdb->object_find_create(cluster_parent_handle, name, strlen(name), &find_handle);
+	while (objdb->object_find_next(find_handle, &object_handle) == 0) {
+		res = copy_config_tree(objdb, object_handle, OBJECT_PARENT_HANDLE, always_create);
+	}
+	objdb->object_find_destroy(find_handle);
+
+	return res;
+}
+
 static int get_cman_globals(struct objdb_iface_ver0 *objdb)
 {
 	unsigned int object_handle;
@@ -954,6 +1023,18 @@ static int cmanpre_readconfig(struct objdb_iface_ver0 *objdb, char **error_strin
 	objdb->object_find_create(OBJECT_PARENT_HANDLE, "cluster", strlen("cluster"), &find_handle);
         objdb->object_find_next(find_handle, &cluster_parent_handle);
 	objdb->object_find_destroy(find_handle);
+	if (!cluster_parent_handle) {
+		sprintf (error_reason, "%s", "Cannot find /cluster/ key in configuration\n");
+		return -1;
+	}
+
+	/* Move these to a place where corosync expects to find them */
+	ret = copy_tree_to_root(objdb, "totem", 0);
+	ret = copy_tree_to_root(objdb, "logging", 0);
+	ret = copy_tree_to_root(objdb, "event", 0);
+	ret = copy_tree_to_root(objdb, "amf", 0);
+	ret = copy_tree_to_root(objdb, "aisexec", 0);
+	ret = copy_tree_to_root(objdb, "service", 1);
 
 	objdb->object_find_create(cluster_parent_handle, "cman", strlen("cman"), &find_handle);
 	if (objdb->object_find_next(find_handle, &object_handle)) {
@@ -973,6 +1054,8 @@ static int cmanpre_readconfig(struct objdb_iface_ver0 *objdb, char **error_strin
 		ret = get_nodename(objdb);
 		add_cman_overrides(objdb);
 	}
+
+
 	if (!ret) {
 		sprintf (error_reason, "%s", "Successfully parsed cman config\n");
 	}
