@@ -1,17 +1,12 @@
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
-#include <sys/socket.h>
-#include <sys/un.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 #include <netdb.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
-#include <openais/saAis.h>
+#include <corosync/saAis.h>
 #include <corosync/confdb.h>
 #include <libxml/parser.h>
 #include <libxml/xpath.h>
@@ -563,7 +558,7 @@ fail:
  *
  * Returns: 0 on success, < 0 on failure
  */
-int _ccs_get_xpathlite(int desc, const char *query, char **rtn, int list)
+static int _ccs_get_xpathlite(int desc, const char *query, char **rtn, int list)
 {
 	int res = 0, confdbres = 0, is_oldlist = 0;
 	int tokens, i;
@@ -627,7 +622,7 @@ fail:
  *
  * Returns: 0 on success, < 0 on failure
  */
-int _ccs_get_fullxpath(int desc, const char *query, char **rtn, int list)
+static int _ccs_get_fullxpath(int desc, const char *query, char **rtn, int list)
 {
 	int res = 0;
 	xmlXPathObjectPtr obj = NULL;
