@@ -108,7 +108,7 @@ all_opt = {
 		"order" : 1 },
 	"port" : {
 		"getopt" : "n:",
-		"help" : "-n <id>        Physical plug number on device",
+		"help" : "-n <id>        Physical plug number on device or name of virtual machine",
 		"order" : 1 },
 	"switch" : {
 		"getopt" : "s:",
@@ -126,7 +126,27 @@ all_opt = {
 		"getopt" : "T",
 		"help" : "",
 		"order" : 1,
-		"obsolete" : "use -o status instead" }
+		"obsolete" : "use -o status instead" },
+	"vmipaddr" : {
+		"getopt" : "A:",
+		"help" : "-A <ip>        IP address or hostname of managed VMware ESX (default localhost)",
+		"order" : 2 },
+	"vmlogin" : {
+		"getopt" : "L:",
+		"help" : "-L <name>      VMware ESX management login name",
+		"order" : 2 },
+	"vmpasswd" : {
+		"getopt" : "P:",
+		"help" : "-P <password>  VMware ESX management login password",
+		"order" : 2 },
+	"vmpasswd_script" : {
+		"getopt" : "B:",
+		"help" : "-B <script>    Script to run to retrieve VMware ESX management password",
+		"order" : 2 },
+	"separator" : {
+		"getopt" : "C:",
+		"help" : "-C <char>	Separator for CSV created by 'list' operation",
+		"order" : 100 }
 }
 
 class fspawn(pexpect.spawn):
@@ -267,7 +287,7 @@ def check_input(device_opt, opt):
 	if 0 == options.has_key("-o"):
 		options["-o"] = "reboot"
 
-	if 0 == ["on", "off", "reboot", "status"].count(options["-o"].lower()):
+	if 0 == ["on", "off", "reboot", "status", "list"].count(options["-o"].lower()):
 		fail_usage("Failed: Unrecognised action '" + options["-o"] + "'")
 
 	if (0 == options.has_key("-l")) and device_opt.count("login") and (device_opt.count("no_login") == 0):
@@ -305,6 +325,23 @@ def check_input(device_opt, opt):
 	if options.has_key("-v") and options.has_key("debug_fh") == 0:
 		options["debug_fh"] = sys.stderr
 
+	if 0 == options.has_key("-C"):
+		options["-C"] = ","
+
+	## VMware
+	#######
+	if options.has_key("-B"):
+		options["-P"] = os.popen(options["-B"]).read().rstrip()
+
+	if (device_opt.count("vmlogin") and (not options.has_key("-L"))):
+		fail_usage("Failed: You have to set login name for VMware ESX management console")
+
+	if (options.has_key("-L") and (not (options.has_key("-P") or options.has_key("-C")))):
+		fail_usage("Failed: You have to enter password or password script for VMware ESX management console")
+
+	if (options.has_key("-L") and (not (options.has_key("-n")))):
+		fail_usage("Failed: You have to enter virtual machine name")
+		
 	return options
 	
 def wait_power_status(tn, options, get_power_fn):
@@ -315,7 +352,20 @@ def wait_power_status(tn, options, get_power_fn):
 			return 1
 	return 0
 
-def fence_action(tn, options, set_power_fn, get_power_fn):
+def fence_action(tn, options, set_power_fn, get_power_fn, get_outlet_list = None):
+	if (options["-o"] == "list" and get_outlet_list == None):		
+		## @todo: exception?
+		## This is just temporal solution, we will remove default value
+		## None as soon as all existing agent will support this operation 
+		print "NOTICE: List option is not working on this device yet"
+		return
+	elif (options["-o"] == "list"):
+		outlets = get_outlet_list(tn, options)
+		## keys can be numbers (port numbers) or strings (names of VM)
+		for o in outlets.keys():
+			(alias, status) = outlets[o]
+			print o + options["-C"] + alias	
+
 	status = get_power_fn(tn, options)
 
 	if options["-o"] == "on":
@@ -363,10 +413,22 @@ def fence_login(options):
 			if options.has_key("ssh_options"):
 				command += ' ' + options["ssh_options"]
 			conn = fspawn(command)
-			result = conn.log_expect(options, [ "ssword:", "Are you sure you want to continue connecting (yes/no)?" ], LOGIN_TIMEOUT)
-			if result == 1:
-				conn.sendline("yes")
-				conn.log_expect(options, "ssword:", LOGIN_TIMEOUT)
+
+			if options.has_key("telnet_over_ssh"):
+				#This is for stupid ssh servers (like ALOM) which behave more like telnet (ignore name and display login prompt)
+				result = conn.log_expect(options, [ re_login, "Are you sure you want to continue connecting (yes/no)?" ], LOGIN_TIMEOUT)
+				if result == 1:
+					conn.sendline("yes") # Host identity confirm
+					conn.log_expect(options, re_login, LOGIN_TIMEOUT)
+
+				conn.sendline(options["-l"])
+				conn.log_expect(options, re_pass, LOGIN_TIMEOUT)
+			else:
+				result = conn.log_expect(options, [ "ssword:", "Are you sure you want to continue connecting (yes/no)?" ], LOGIN_TIMEOUT)
+				if result == 1:
+					conn.sendline("yes")
+					conn.log_expect(options, "ssword:", LOGIN_TIMEOUT)
+
 			conn.sendline(options["-p"])
 			conn.log_expect(options, options["-c"], LOGIN_TIMEOUT)
 		elif options.has_key("-x") and 1 == options.has_key("-k"):
