@@ -36,7 +36,7 @@ int cman_nodes_count;
 struct fenced_node nodes[MAX_NODES];
 char *prog_name;
 int operation;
-int verbose = 0;
+int ls_all_nodes = 0;
 int inquorate_fail = 0;
 int wait_join = 0;			 /* default: don't wait for join */
 int wait_leave = 0;			 /* default: don't wait for leave */
@@ -371,6 +371,49 @@ static int node_compare(const void *va, const void *vb)
 	return a->nodeid - b->nodeid;
 }
 
+/* copied from fence/fenced/fd.h, should probably be in libfenced.h */
+#define CGST_WAIT_CONDITIONS	1
+#define CGST_WAIT_MESSAGES	2
+#define CGST_WAIT_FENCING	3
+
+static char *wait_str(int state)
+{
+	switch (state) {
+	case 0:
+		return "none";
+	case CGST_WAIT_CONDITIONS:
+		return "quorum";
+	case CGST_WAIT_MESSAGES:
+		return "messages";
+	case CGST_WAIT_FENCING:
+		return "fencing";
+	}
+	return "unknown";
+}
+
+/* copied from fence/fenced/fd.h, should probably be in libfenced.h */
+#define VIC_DONE_AGENT          1
+#define VIC_DONE_MEMBER         2
+#define VIC_DONE_OVERRIDE       3
+#define VIC_DONE_EXTERNAL       4
+
+static char *how_str(int how)
+{
+	switch (how) {
+	case 0:
+		return "none";
+	case VIC_DONE_AGENT:
+		return "agent";
+	case VIC_DONE_MEMBER:
+		return "member";
+	case VIC_DONE_OVERRIDE:
+		return "override";
+	case VIC_DONE_EXTERNAL:
+		return "external";
+	}
+	return "unknown";
+}
+
 static int do_list(void)
 {
 	struct fenced_domain d;
@@ -380,13 +423,14 @@ static int do_list(void)
 
 	rv = fenced_domain_info(&d);
 	if (rv < 0)
-		goto fail;
+		exit(EXIT_SUCCESS); /* fenced probably not running */
 
 	printf("fence domain\n");
 	printf("member count  %d\n", d.member_count);
 	printf("victim count  %d\n", d.victim_count);
 	printf("victim now    %d\n", d.current_victim);
 	printf("master nodeid %d\n", d.master_nodeid);
+	printf("wait state    %s\n", wait_str(d.state));
 	printf("members       ");
 
 	node_count = 0;
@@ -408,7 +452,7 @@ static int do_list(void)
 	}
 	printf("\n");
 
-	if (!verbose) {
+	if (!ls_all_nodes) {
 		printf("\n");
 		exit(EXIT_SUCCESS);
 	}
@@ -427,12 +471,12 @@ static int do_list(void)
 
 	np = nodes;
 	for (i = 0; i < node_count; i++) {
-		printf("nodeid %d member %d victim %d last fence master %d how %d\n",
+		printf("nodeid %d member %d victim %d last fence master %d how %s\n",
 				np->nodeid,
 				np->member,
 				np->victim,
 				np->last_fenced_master,
-				np->last_fenced_how);
+				how_str(np->last_fenced_how));
 		np++;
 	}
 	printf("\n");
@@ -456,6 +500,7 @@ static void print_usage(void)
 	printf("  dump		   Dump debug buffer from fenced\n");
 	printf("\n");
 	printf("Options:\n");
+	printf("  -n               Show all node information in ls\n");
 	printf("  -m <seconds>     Delay join up to <seconds> for all nodes in cluster.conf\n");
 	printf("                   to be cluster members\n");
 	printf("  -w               Wait for join or leave to complete\n");
@@ -466,7 +511,7 @@ static void print_usage(void)
 	printf("\n");
 }
 
-#define OPTION_STRING "vVht:wQm:"
+#define OPTION_STRING "Vht:wQm:n"
 
 static void decode_arguments(int argc, char *argv[])
 {
@@ -485,8 +530,8 @@ static void decode_arguments(int argc, char *argv[])
 			exit(EXIT_SUCCESS);
 			break;
 
-		case 'v':
-			verbose++;
+		case 'n':
+			ls_all_nodes = 1;
 			break;
 
 		case 'h':
