@@ -4,6 +4,7 @@
 #define DEFAULT_GROUPD_COMPAT 2
 #define DEFAULT_DEBUG_LOGSYS 0
 #define DEFAULT_CLEAN_START 0
+#define DEFAULT_SKIP_UNDEFINED 0
 #define DEFAULT_POST_JOIN_DELAY 6
 #define DEFAULT_POST_FAIL_DELAY 0
 #define DEFAULT_OVERRIDE_TIME 3
@@ -12,6 +13,7 @@
 extern int optd_groupd_compat;
 extern int optd_debug_logsys;
 extern int optd_clean_start;
+extern int optd_skip_undefined;
 extern int optd_post_join_delay;
 extern int optd_post_fail_delay;
 extern int optd_override_time;
@@ -20,6 +22,7 @@ extern int optd_override_path;
 extern int cfgd_groupd_compat;
 extern int cfgd_debug_logsys;
 extern int cfgd_clean_start;
+extern int cfgd_skip_undefined;
 extern int cfgd_post_join_delay;
 extern int cfgd_post_fail_delay;
 extern int cfgd_override_time;
