@@ -1,10 +1,29 @@
 #include "fd.h"
 #include "config.h"
 
-static unsigned int protocol_active[3] = {1, 0, 0};
-static cpg_handle_t cpg_handle_daemon;
-static struct cpg_address daemon_member_list[MAX_NODES];
-static int daemon_member_list_entries;
+struct protocol_version {
+	uint16_t major;
+	uint16_t minor;
+	uint16_t patch;
+	uint16_t flags;
+};
+
+struct protocol {
+	union {
+		struct protocol_version dm_ver;
+		uint16_t                daemon_max[4];
+	};
+	union {
+		struct protocol_version dr_ver;
+		uint16_t                daemon_run[4];
+	};
+};
+
+struct node_daemon {
+	struct list_head list;
+	int nodeid;
+	struct protocol proto;
+};
 
 struct member {
 	struct list_head list;
@@ -46,6 +65,13 @@ struct id_info {
 	uint64_t fence_external_time;
 };
 
+static cpg_handle_t cpg_handle_daemon;
+static int daemon_cpg_fd;
+static struct protocol our_protocol;
+static struct list_head daemon_nodes;
+static struct cpg_address daemon_member[MAX_NODES];
+static int daemon_member_count;
+
 static void fd_info_in(struct fd_info *fi)
 {
 	fi->fd_info_size  = le32_to_cpu(fi->fd_info_size);
@@ -136,9 +162,9 @@ static void fd_send_message(struct fd *fd, char *buf, int len)
 	struct fd_header *hd = (struct fd_header *) buf;
 	int type = hd->type;
 
-	hd->version[0]  = cpu_to_le16(protocol_active[0]);
-	hd->version[1]  = cpu_to_le16(protocol_active[1]);
-	hd->version[2]  = cpu_to_le16(protocol_active[2]);
+	hd->version[0]  = cpu_to_le16(our_protocol.daemon_run[0]);
+	hd->version[1]  = cpu_to_le16(our_protocol.daemon_run[1]);
+	hd->version[2]  = cpu_to_le16(our_protocol.daemon_run[2]);
 	hd->type	= cpu_to_le16(hd->type);
 	hd->nodeid      = cpu_to_le32(our_nodeid);
 	hd->to_nodeid   = cpu_to_le32(hd->to_nodeid);
@@ -318,9 +344,15 @@ static void save_history(struct fd *fd, struct fd_info *fi, struct id_info *ids)
 	id = ids;
 
 	for (i = 0; i < fi->id_info_count; i++) {
+		/* create history entries for nodes that were domain members
+		   prior to our joining the domain */
+		node_history_init(fd, id->nodeid);
+
 		node = get_node_history(fd, id->nodeid);
-		if (!node)
+		if (!node) {
+			log_error("save_history no nodeid %d", id->nodeid);
 			goto next;
+		}
 
 		if (!node->fence_time && id->fence_time) {
 			node->fence_master = id->fence_master;
@@ -548,11 +580,12 @@ static int wait_messages_done(struct fd *fd)
 	}
 
 	if (need) {
-		log_debug("wait_messages need %d of %d", need, total);
+		log_debug("wait_messages cg %u need %d of %d",
+			  cg->seq, need, total);
 		return 0;
 	}
 
-	log_debug("wait_messages got all %d", total);
+	log_debug("wait_messages cg %u got all %d", cg->seq, total);
 	return 1;
 }
 
@@ -1013,6 +1046,8 @@ static void apply_changes(struct fd *fd)
 	case CGST_WAIT_MESSAGES:
 		if (wait_messages_done(fd)) {
 			set_master(fd);
+			cg->state = CGST_WAIT_FENCING;  /* for queries */
+
 			if (fd->master == our_nodeid) {
 				delay_fencing(fd, nodes_added(fd));
 				fence_victims(fd);
@@ -1213,6 +1248,21 @@ static void confchg_cb(cpg_handle_t handle, struct cpg_name *group_name,
 
 	if (cg->we_joined)
 		add_victims_init(fd, cg);
+
+	apply_changes(fd);
+}
+
+static void fd_header_in(struct fd_header *hd)
+{
+	hd->version[0]  = le16_to_cpu(hd->version[0]);
+	hd->version[1]  = le16_to_cpu(hd->version[1]);
+	hd->version[2]  = le16_to_cpu(hd->version[2]);
+	hd->type        = le16_to_cpu(hd->type);
+	hd->nodeid      = le32_to_cpu(hd->nodeid);
+	hd->to_nodeid   = le32_to_cpu(hd->to_nodeid);
+	hd->global_id   = le32_to_cpu(hd->global_id);
+	hd->flags       = le32_to_cpu(hd->flags);
+	hd->msgdata     = le32_to_cpu(hd->msgdata);
 }
 
 static void deliver_cb(cpg_handle_t handle, struct cpg_name *group_name,
@@ -1227,23 +1277,21 @@ static void deliver_cb(cpg_handle_t handle, struct cpg_name *group_name,
 		return;
 	}
 
+	if (len < sizeof(*hd)) {
+		log_error("deliver_cb short message %d", len);
+		return;
+	}
+
 	hd = (struct fd_header *)data;
+	fd_header_in(hd);
 
-	hd->version[0]  = le16_to_cpu(hd->version[0]);
-	hd->version[1]  = le16_to_cpu(hd->version[1]);
-	hd->version[2]  = le16_to_cpu(hd->version[2]);
-	hd->type        = le16_to_cpu(hd->type);
-	hd->nodeid      = le32_to_cpu(hd->nodeid);
-	hd->to_nodeid   = le32_to_cpu(hd->to_nodeid);
-	hd->global_id   = le32_to_cpu(hd->global_id);
-	hd->flags       = le32_to_cpu(hd->flags);
-	hd->msgdata     = le32_to_cpu(hd->msgdata);
-
-	if (hd->version[0] != protocol_active[0]) {
+	if (hd->version[0] != our_protocol.daemon_run[0] ||
+	    hd->version[1] != our_protocol.daemon_run[1]) {
 		log_error("reject message from %d version %u.%u.%u vs %u.%u.%u",
 			  nodeid, hd->version[0], hd->version[1],
-			  hd->version[2], protocol_active[0],
-			  protocol_active[1], protocol_active[2]);
+			  hd->version[2], our_protocol.daemon_run[0],
+			  our_protocol.daemon_run[1],
+			  our_protocol.daemon_run[2]);
 		return;
 	}
 
@@ -1268,6 +1316,8 @@ static void deliver_cb(cpg_handle_t handle, struct cpg_name *group_name,
 	default:
 		log_error("unknown msg type %d", hd->type);
 	}
+
+	apply_changes(fd);
 }
 
 static cpg_callbacks_t cpg_callbacks = {
@@ -1291,8 +1341,6 @@ static void process_fd_cpg(int ci)
 		log_error("cpg_dispatch error %d", error);
 		return;
 	}
-
-	apply_changes(fd);
 }
 
 int fd_join(struct fd *fd)
@@ -1372,6 +1420,320 @@ int fd_leave(struct fd *fd)
 	return 0;
 }
 
+static struct node_daemon *get_node_daemon(int nodeid)
+{
+	struct node_daemon *node;
+
+	list_for_each_entry(node, &daemon_nodes, list) {
+		if (node->nodeid == nodeid)
+			return node;
+	}
+	return NULL;
+}
+
+static void add_node_daemon(int nodeid)
+{
+	struct node_daemon *node;
+
+	if (get_node_daemon(nodeid))
+		return;
+
+	node = malloc(sizeof(struct node_daemon));
+	if (!node) {
+		log_error("add_node_daemon no mem");
+		return;
+	}
+	memset(node, 0, sizeof(struct node_daemon));
+	node->nodeid = nodeid;
+	list_add_tail(&node->list, &daemon_nodes);
+}
+
+static void pv_in(struct protocol_version *pv)
+{
+	pv->major = le16_to_cpu(pv->major);
+	pv->minor = le16_to_cpu(pv->minor);
+	pv->patch = le16_to_cpu(pv->patch);
+	pv->flags = le16_to_cpu(pv->flags);
+}
+
+static void pv_out(struct protocol_version *pv)
+{
+	pv->major = cpu_to_le16(pv->major);
+	pv->minor = cpu_to_le16(pv->minor);
+	pv->patch = cpu_to_le16(pv->patch);
+	pv->flags = cpu_to_le16(pv->flags);
+}
+
+static void protocol_in(struct protocol *proto)
+{
+	pv_in(&proto->dm_ver);
+	pv_in(&proto->dr_ver);
+}
+
+static void protocol_out(struct protocol *proto)
+{
+	pv_out(&proto->dm_ver);
+	pv_out(&proto->dr_ver);
+}
+
+/* go through member list saved in last confchg, see if we have received a
+   proto message from each */
+
+static int all_protocol_messages(void)
+{
+	struct node_daemon *node;
+	int i;
+
+	if (!daemon_member_count)
+		return 0;
+
+	for (i = 0; i < daemon_member_count; i++) {
+		node = get_node_daemon(daemon_member[i].nodeid);
+		if (!node) {
+			log_error("all_protocol_messages no node %d",
+				  daemon_member[i].nodeid);
+			return 0;
+		}
+
+		if (!node->proto.daemon_max[0])
+			return 0;
+	}
+	return 1;
+}
+
+static int pick_min_protocol(struct protocol *proto)
+{
+	uint16_t mind[4];
+	struct node_daemon *node;
+	int i;
+
+	memset(&mind, 0, sizeof(mind));
+
+	/* first choose the minimum major */
+
+	for (i = 0; i < daemon_member_count; i++) {
+		node = get_node_daemon(daemon_member[i].nodeid);
+		if (!node) {
+			log_error("pick_min_protocol no node %d",
+				  daemon_member[i].nodeid);
+			return -1;
+		}
+
+		if (!mind[0] || node->proto.daemon_max[0] < mind[0])
+			mind[0] = node->proto.daemon_max[0];
+	}
+
+	if (!mind[0]) {
+		log_error("pick_min_protocol zero major number");
+		return -1;
+	}
+
+	/* second pick the minimum minor with the chosen major */
+
+	for (i = 0; i < daemon_member_count; i++) {
+		node = get_node_daemon(daemon_member[i].nodeid);
+		if (!node)
+			continue;
+
+		if (mind[0] == node->proto.daemon_max[0]) {
+			if (!mind[1] || node->proto.daemon_max[1] < mind[1])
+				mind[1] = node->proto.daemon_max[1];
+		}
+	}
+
+	if (!mind[1]) {
+		log_error("pick_min_protocol zero minor number");
+		return -1;
+	}
+
+	/* third pick the minimum patch with the chosen major.minor */
+
+	for (i = 0; i < daemon_member_count; i++) {
+		node = get_node_daemon(daemon_member[i].nodeid);
+		if (!node)
+			continue;
+
+		if (mind[0] == node->proto.daemon_max[0] &&
+		    mind[1] == node->proto.daemon_max[1]) {
+			if (!mind[2] || node->proto.daemon_max[2] < mind[2])
+				mind[2] = node->proto.daemon_max[2];
+		}
+	}
+
+	if (!mind[2]) {
+		log_error("pick_min_protocol zero patch number");
+		return -1;
+	}
+
+	memcpy(&proto->daemon_run, &mind, sizeof(mind));
+	return 0;
+}
+
+static void receive_protocol(struct fd_header *hd, int len)
+{
+	struct protocol *p;
+	struct node_daemon *node;
+
+	p = (struct protocol *)((char *)hd + sizeof(struct fd_header));
+	protocol_in(p);
+
+	if (len < sizeof(struct fd_header) + sizeof(struct protocol)) {
+		log_error("receive_protocol invalid len %d from %d",
+			  len, hd->nodeid);
+		return;
+	}
+
+	/* zero is an invalid version value */
+
+	if (!p->daemon_max[0] || !p->daemon_max[1] || !p->daemon_max[2]) {
+		log_error("receive_protocol invalid max value from %d "
+			  "daemon %u.%u.%u", hd->nodeid,
+			  p->daemon_max[0], p->daemon_max[1], p->daemon_max[2]);
+		return;
+	}
+
+	/* the run values will be zero until a version is set, after
+	   which none of the run values can be zero */
+
+	if (p->daemon_run[0] && (!p->daemon_run[1] || !p->daemon_run[2])) {
+		log_error("receive_protocol invalid run value from %d "
+			  "daemon %u.%u.%u", hd->nodeid,
+			  p->daemon_run[0], p->daemon_run[1], p->daemon_run[2]);
+		return;
+	}
+
+	/* if we have zero run values, and this msg has non-zero run values,
+	   then adopt them as ours; otherwise save this proto message */
+
+	if (our_protocol.daemon_run[0])
+		return;
+
+	if (p->daemon_run[0]) {
+		memcpy(&our_protocol.daemon_run, &p->daemon_run,
+		       sizeof(struct protocol_version));
+		log_debug("run protocol from nodeid %d", hd->nodeid);
+		return;
+	}
+
+	/* save this node's proto so we can tell when we've got all, and
+	   use it to select a minimum protocol from all */
+
+	node = get_node_daemon(hd->nodeid);
+	if (!node) {
+		log_error("receive_protocol no node %d", hd->nodeid);
+		return;
+	}
+	memcpy(&node->proto, p, sizeof(struct protocol));
+}
+
+static void send_protocol(struct protocol *proto)
+{
+	struct fd_header *hd;
+	struct protocol *pr;
+	char *buf;
+	int len;
+
+	len = sizeof(struct fd_header) + sizeof(struct protocol);
+	buf = malloc(len);
+	if (!buf) {
+		log_error("send_protocol no mem %d", len);
+		return;
+	}
+	memset(buf, 0, len);
+
+	hd = (struct fd_header *)buf;
+	pr = (struct protocol *)(buf + sizeof(*hd));
+
+	hd->type = cpu_to_le16(FD_MSG_PROTOCOL);
+	hd->nodeid = cpu_to_le32(our_nodeid);
+
+	memcpy(pr, proto, sizeof(struct protocol));
+	protocol_out(pr);
+
+	_send_message(cpg_handle_daemon, buf, len, FD_MSG_PROTOCOL);
+}
+
+int set_protocol(void)
+{
+	struct protocol proto;
+	struct pollfd pollfd;
+	int sent_proposal = 0;
+	int rv;
+
+	memset(&pollfd, 0, sizeof(pollfd));
+	pollfd.fd = daemon_cpg_fd;
+	pollfd.events = POLLIN;
+
+	while (1) {
+		if (our_protocol.daemon_run[0])
+			break;
+
+		if (!sent_proposal && all_protocol_messages()) {
+			/* propose a protocol; look through info from all
+			   nodes and pick the min and propose that */
+
+			sent_proposal = 1;
+
+			/* copy our max values */
+			memcpy(&proto, &our_protocol, sizeof(struct protocol));
+
+			rv = pick_min_protocol(&proto);
+			if (rv < 0)
+				return rv;
+
+			log_debug("set_protocol member_count %d propose "
+				  "daemon %u.%u.%u", daemon_member_count,
+				  proto.daemon_run[0], proto.daemon_run[1],
+				  proto.daemon_run[2]);
+
+			send_protocol(&proto);
+		}
+
+		/* only process messages/events from daemon cpg until protocol
+		   is established */
+
+		rv = poll(&pollfd, 1, -1);
+		if (rv == -1 && errno == EINTR) {
+			if (daemon_quit)
+				return -1;
+			continue;
+		}
+		if (rv < 0) {
+			log_error("set_protocol poll errno %d", errno);
+			return -1;
+		}
+
+		if (pollfd.revents & POLLIN)
+			process_cpg(0);
+		if (pollfd.revents & (POLLERR | POLLHUP | POLLNVAL)) {
+			log_error("set_protocol poll revents %u",
+				  pollfd.revents);
+			return -1;
+		}
+	}
+
+	if (our_protocol.daemon_run[0] != our_protocol.daemon_max[0] ||
+	    our_protocol.daemon_run[1] > our_protocol.daemon_max[1]) {
+		log_error("incompatible daemon protocol run %u.%u.%u max %u.%u.%u",
+			our_protocol.daemon_run[0],
+			our_protocol.daemon_run[1],
+			our_protocol.daemon_run[2],
+			our_protocol.daemon_max[0],
+			our_protocol.daemon_max[1],
+			our_protocol.daemon_max[2]);
+		return -1;
+	}
+
+	log_debug("daemon run %u.%u.%u max %u.%u.%u",
+		  our_protocol.daemon_run[0],
+		  our_protocol.daemon_run[1],
+		  our_protocol.daemon_run[2],
+		  our_protocol.daemon_max[0],
+		  our_protocol.daemon_max[1],
+		  our_protocol.daemon_max[2]);
+	return 0;
+}
+
 /* process_cpg(), setup_cpg(), close_cpg() are for the "daemon" cpg which
    tracks the presence of other daemons; it's not the fenced domain cpg.
    Joining this cpg tells others that we don't have uncontrolled dlm/gfs
@@ -1381,6 +1743,23 @@ int fd_leave(struct fd *fd)
 static void deliver_cb_daemon(cpg_handle_t handle, struct cpg_name *group_name,
 		uint32_t nodeid, uint32_t pid, void *data, int len)
 {
+	struct fd_header *hd;
+
+	if (len < sizeof(*hd)) {
+		log_error("deliver_cb short message %d", len);
+		return;
+	}
+
+	hd = (struct fd_header *)data;
+	fd_header_in(hd);
+
+	switch (hd->type) {
+	case FD_MSG_PROTOCOL:
+		receive_protocol(hd, len);
+		break;
+	default:
+		log_error("deliver_cb_daemon unknown msg type %d", hd->type);
+	}
 }
 
 static void confchg_cb_daemon(cpg_handle_t handle, struct cpg_name *group_name,
@@ -1388,10 +1767,18 @@ static void confchg_cb_daemon(cpg_handle_t handle, struct cpg_name *group_name,
 		struct cpg_address *left_list, int left_list_entries,
 		struct cpg_address *joined_list, int joined_list_entries)
 {
-	memset(&daemon_member_list, 0, sizeof(daemon_member_list));
-	memcpy(&daemon_member_list, member_list,
-	       member_list_entries * sizeof(struct cpg_address));
-	daemon_member_list_entries = member_list_entries;
+	int i;
+
+	if (joined_list_entries)
+		send_protocol(&our_protocol);
+
+	memset(&daemon_member, 0, sizeof(daemon_member));
+	daemon_member_count = member_list_entries;
+
+	for (i = 0; i < member_list_entries; i++) {
+		daemon_member[i] = member_list[i];
+		add_node_daemon(member_list[i].nodeid);
+	}
 }
 
 static cpg_callbacks_t cpg_callbacks_daemon = {
@@ -1414,8 +1801,8 @@ int in_daemon_member_list(int nodeid)
 
 	cpg_dispatch(cpg_handle_daemon, CPG_DISPATCH_ALL);
 
-	for (i = 0; i < daemon_member_list_entries; i++) {
-		if (daemon_member_list[i].nodeid == nodeid)
+	for (i = 0; i < daemon_member_count; i++) {
+		if (daemon_member[i].nodeid == nodeid)
 			return 1;
 	}
 	return 0;
@@ -1424,26 +1811,30 @@ int in_daemon_member_list(int nodeid)
 int setup_cpg(void)
 {
 	cpg_error_t error;
-	cpg_handle_t h;
 	struct cpg_name name;
-	int i = 0, f;
+	int i = 0;
 
-	error = cpg_initialize(&h, &cpg_callbacks_daemon);
+	INIT_LIST_HEAD(&daemon_nodes);
+
+	memset(&our_protocol, 0, sizeof(our_protocol));
+	our_protocol.daemon_max[0] = 1;
+	our_protocol.daemon_max[1] = 1;
+	our_protocol.daemon_max[2] = 1;
+
+	error = cpg_initialize(&cpg_handle_daemon, &cpg_callbacks_daemon);
 	if (error != CPG_OK) {
 		log_error("daemon cpg_initialize error %d", error);
 		goto fail;
 	}
 
-	cpg_fd_get(h, &f);
-
-	cpg_handle_daemon = h;
+	cpg_fd_get(cpg_handle_daemon, &daemon_cpg_fd);
 
 	memset(&name, 0, sizeof(name));
 	sprintf(name.value, "fenced:daemon");
 	name.length = strlen(name.value) + 1;
 
  retry:
-	error = cpg_join(h, &name);
+	error = cpg_join(cpg_handle_daemon, &name);
 	if (error == CPG_ERR_TRY_AGAIN) {
 		sleep(1);
 		if (!(++i % 10))
@@ -1455,11 +1846,11 @@ int setup_cpg(void)
 		goto fail;
 	}
 
-	log_debug("setup_cpg %d", f);
-	return f;
+	log_debug("setup_cpg %d", daemon_cpg_fd);
+	return daemon_cpg_fd;
 
  fail:
-	cpg_finalize(h);
+	cpg_finalize(cpg_handle_daemon);
 	return -1;
 }
 
@@ -1469,7 +1860,7 @@ void close_cpg(void)
 	struct cpg_name name;
 	int i = 0;
 
-	if (!cpg_handle_daemon)
+	if (!cpg_handle_daemon || cluster_down)
 		return;
 
 	memset(&name, 0, sizeof(name));
@@ -1492,37 +1883,45 @@ int set_node_info(struct fd *fd, int nodeid, struct fenced_node *nodeinfo)
 {
 	struct node_history *node;
 	struct member *memb;
+	struct change *cg;
 
 	nodeinfo->nodeid = nodeid;
 	nodeinfo->victim = is_victim(fd, nodeid);
 
-	if (!fd->started_change)
-		goto history;
+	if (list_empty(&fd->changes))
+		cg = fd->started_change;
+	else
+		cg = list_first_entry(&fd->changes, struct change, list);
 
-	memb = find_memb(fd->started_change, nodeid);
-	if (memb)
-		nodeinfo->member = memb->disallowed ? 0 : 1;
+	if (cg) {
+		memb = find_memb(cg, nodeid);
+		if (memb)
+			nodeinfo->member = memb->disallowed ? -1 : 1;
+	}
 
- history:
 	node = get_node_history(fd, nodeid);
-	if (!node)
-		return 0;
-
-	nodeinfo->last_fenced_master = node->fence_master;
-	nodeinfo->last_fenced_how = node->fence_how;
-	nodeinfo->last_fenced_time = node->fence_time;
+	if (node) {
+		nodeinfo->last_fenced_master = node->fence_master;
+		nodeinfo->last_fenced_how = node->fence_how;
+		nodeinfo->last_fenced_time = node->fence_time;
+	}
 
 	return 0;
 }
 
 int set_domain_info(struct fd *fd, struct fenced_domain *domain)
 {
-	struct change *cg = fd->started_change;
+	struct change *cg;
 
-	if (cg) {
+	if (list_empty(&fd->changes)) {
+		if (fd->started_change)
+			domain->member_count = fd->started_change->member_count;
+	} else {
+		cg = list_first_entry(&fd->changes, struct change, list);
 		domain->member_count = cg->member_count;
 		domain->state = cg->state;
 	}
+
 	domain->master_nodeid = fd->master;
 	domain->victim_count = list_count(&fd->victims);
 	domain->current_victim = fd->current_victim;
@@ -1547,7 +1946,7 @@ int set_domain_nodes(struct fd *fd, int option, int *node_count,
 		nodes = malloc(count * sizeof(struct fenced_node));
 		if (!nodes)
 			return -ENOMEM;
-		memset(nodes, 0, sizeof(*nodes));
+		memset(nodes, 0, count * sizeof(struct fenced_node));
 
 		n = nodes;
 		list_for_each_entry(memb, &cg->members, list)
@@ -1561,7 +1960,7 @@ int set_domain_nodes(struct fd *fd, int option, int *node_count,
 		nodes = malloc(count * sizeof(struct fenced_node));
 		if (!nodes)
 			return -ENOMEM;
-		memset(nodes, 0, sizeof(*nodes));
+		memset(nodes, 0, count * sizeof(struct fenced_node));
 
 		n = nodes;
 		list_for_each_entry(nh, &fd->node_history, list)
