@@ -722,6 +722,7 @@ void cluster_dead(int ci)
 {
 	log_error("cluster is down, exiting");
 	daemon_quit = 1;
+	cluster_down = 1;
 }
 
 static void loop(void)
@@ -773,6 +774,12 @@ static void loop(void)
 	}
 	log_debug("group_mode %d compat %d", group_mode, cfgd_groupd_compat);
 
+	if (group_mode == GROUP_LIBCPG) {
+		rv = set_protocol();
+		if (rv < 0)
+			goto out;
+	}
+
 	for (;;) {
 		rv = poll(pollfd, client_maxi + 1, -1);
 		if (rv == -1 && errno == EINTR) {
@@ -1045,6 +1052,7 @@ void daemon_dump_save(void)
 
 int daemon_debug_opt;
 int daemon_quit;
+int cluster_down;
 struct list_head domains;
 int cman_quorate;
 int our_nodeid;
