@@ -157,7 +157,7 @@ static struct lockspace *create_ls(char *name)
 	ls = malloc(sizeof(*ls));
 	if (!ls)
 		goto out;
-	memset(ls, 0, sizeof(*ls));
+	memset(ls, 0, sizeof(struct lockspace));
 	strncpy(ls->name, name, DLM_LOCKSPACE_LEN);
 
 	INIT_LIST_HEAD(&ls->changes);
@@ -531,6 +531,8 @@ static void query_node_info(int fd, char *name, int nodeid)
 		goto out;
 	}
 
+	memset(&node, 0, sizeof(node));
+
 	if (group_mode == GROUP_LIBGROUP)
 		rv = set_node_info_group(ls, nodeid, &node);
 	else
@@ -860,6 +862,7 @@ void cluster_dead(int ci)
 {
 	log_error("cluster is down, exiting");
 	daemon_quit = 1;
+	cluster_down = 1;
 }
 
 static void loop(void)
@@ -926,7 +929,11 @@ static void loop(void)
 		rv = setup_cpg();
 		if (rv < 0)
 			goto out;
-		/* client_add(rv, process_cpg, cluster_dead); */
+		client_add(rv, process_cpg, cluster_dead);
+
+		rv = set_protocol();
+		if (rv < 0)
+			goto out;
 
 		if (cfgd_enable_deadlk) {
 			rv = setup_netlink();
@@ -995,6 +1002,8 @@ static void loop(void)
  out:
 	if (cfgd_groupd_compat)
 		close_groupd();
+	if (group_mode == GROUP_LIBCPG)
+		close_cpg();
 	clear_configfs();
 	close_logging();
 	close_ccs();
@@ -1281,6 +1290,7 @@ void daemon_dump_save(void)
 
 int daemon_debug_opt;
 int daemon_quit;
+int cluster_down;
 int poll_fencing;
 int poll_quorum;
 int poll_fs;
