@@ -269,13 +269,15 @@ static int daemon_member_count;
     would let everyone start again.]
 */
 
-static void process_mountgroup(struct mountgroup *mg);
+static void apply_changes_recovery(struct mountgroup *mg);
 static void send_withdraw_acks(struct mountgroup *mg);
 static void leave_mountgroup(struct mountgroup *mg, int mnterr);
 
 static char *msg_name(int type)
 {
 	switch (type) {
+	case GFS_MSG_PROTOCOL:
+		return "protocol";
 	case GFS_MSG_START:
 		return "start";
 	case GFS_MSG_MOUNT_DONE:
@@ -698,7 +700,7 @@ void process_dlmcontrol(int ci)
 
 	poll_dlm = 0;
 
-	process_mountgroup(mg);
+	apply_changes_recovery(mg);
 }
 
 static int check_dlm_notify_done(struct mountgroup *mg)
@@ -814,11 +816,12 @@ static int wait_messages_done(struct mountgroup *mg)
 	}
 
 	if (need) {
-		log_group(mg, "wait_messages need %d of %d", need, total);
+		log_group(mg, "wait_messages cg %u need %d of %d",
+			  cg->seq, need, total);
 		return 0;
 	}
 
-	log_group(mg, "wait_messages got all %d", total);
+	log_group(mg, "wait_messages cg %u got all %d", cg->seq, total);
 	return 1;
 }
 
@@ -2182,7 +2185,7 @@ void process_recovery_uevent(char *table)
 		}
 	}
 
-	process_mountgroup(mg);
+	apply_changes_recovery(mg);
 }
 
 static void start_journal_recovery(struct mountgroup *mg, int jid)
@@ -2299,7 +2302,7 @@ static void apply_recovery(struct mountgroup *mg)
 	}
 }
 
-static void process_mountgroup(struct mountgroup *mg)
+static void apply_changes_recovery(struct mountgroup *mg)
 {
 	if (!list_empty(&mg->changes))
 		apply_changes(mg);
@@ -2313,7 +2316,7 @@ void process_mountgroups(void)
 	struct mountgroup *mg, *safe;
 
 	list_for_each_entry_safe(mg, safe, &mountgroups, list)
-		process_mountgroup(mg);
+		apply_changes_recovery(mg);
 }
 
 static int add_change(struct mountgroup *mg,
@@ -2474,7 +2477,7 @@ static void confchg_cb(cpg_handle_t handle, struct cpg_name *group_name,
 	if (rv)
 		return;
 
-	process_mountgroup(mg);
+	apply_changes_recovery(mg);
 }
 
 static void gfs_header_in(struct gfs_header *hd)
@@ -2562,7 +2565,7 @@ static void deliver_cb(cpg_handle_t handle, struct cpg_name *group_name,
 		log_error("unknown msg type %d", hd->type);
 	}
 
-	process_mountgroup(mg);
+	apply_changes_recovery(mg);
 }
 
 static cpg_callbacks_t cpg_callbacks = {
@@ -3082,7 +3085,7 @@ int set_protocol(void)
 	}
 
 	if (our_protocol.daemon_run[0] != our_protocol.daemon_max[0] ||
-	    our_protocol.daemon_run[1] != our_protocol.daemon_max[1]) {
+	    our_protocol.daemon_run[1] > our_protocol.daemon_max[1]) {
 		log_error("incompatible daemon protocol run %u.%u.%u max %u.%u.%u",
 			our_protocol.daemon_run[0],
 			our_protocol.daemon_run[1],
@@ -3094,7 +3097,7 @@ int set_protocol(void)
 	}
 
 	if (our_protocol.kernel_run[0] != our_protocol.kernel_max[0] ||
-	    our_protocol.kernel_run[1] != our_protocol.kernel_max[1]) {
+	    our_protocol.kernel_run[1] > our_protocol.kernel_max[1]) {
 		log_error("incompatible kernel protocol run %u.%u.%u max %u.%u.%u",
 			our_protocol.kernel_run[0],
 			our_protocol.kernel_run[1],
@@ -3240,7 +3243,7 @@ void close_cpg(void)
 	struct cpg_name name;
 	int i = 0;
 
-	if (!cpg_handle_daemon)
+	if (!cpg_handle_daemon || cluster_down)
 		return;
 
 	memset(&name, 0, sizeof(name));
