@@ -18,6 +18,10 @@
 #include "libfenced.h"
 #include "libdlmcontrol.h"
 #include "libgfscontrol.h"
+#include "copyright.cf"
+
+#define GROUP_LIBGROUP			2
+#define GROUP_LIBCPG			3
 
 #define MAX_NODES			128
 #define MAX_LS				128
@@ -33,6 +37,8 @@ static int operation;
 static int opt_ind;
 static int verbose;
 static int all_daemons;
+static int ls_all_nodes;
+static int print_header_done;
 
 
 static int do_write(int fd, void *buf, size_t count)
@@ -79,12 +85,16 @@ static void print_usage(void)
 	printf("\n");
 	printf("Options:\n");
 	printf("  -v               Verbose output, extra event information\n");
+	printf("  -a               fence_tool ls; dlm_tool ls; gfs_control ls\n");
+	printf("  -n               Show all node information with -a\n");
 	printf("  -h               Print this help, then exit\n");
 	printf("  -V               Print program version information, then exit\n");
 	printf("\n");
 	printf("Display group information from groupd\n");
 	printf("ls                 Show information for all groups\n");
-	printf("ls <level> <name>  Show information one group\n");
+	printf("ls <level> <name>  Show information one group.  If\n");
+	printf("                   we are not a member of the group,\n");
+	printf("                   return 1.\n");
 	printf("\n");
 	printf("Display debugging information\n");
 	printf("dump               Show debug log from groupd\n");
@@ -96,7 +106,7 @@ static void print_usage(void)
 	printf("\n");
 }
 
-#define OPTION_STRING "ahVv"
+#define OPTION_STRING "ahVvn"
 
 static void decode_arguments(int argc, char **argv)
 {
@@ -111,6 +121,10 @@ static void decode_arguments(int argc, char **argv)
 			all_daemons = 1;
 			break;
 
+		case 'n':
+			ls_all_nodes = 1;
+			break;
+
 		case 'v':
 			verbose = 1;
 			break;
@@ -123,7 +137,7 @@ static void decode_arguments(int argc, char **argv)
 		case 'V':
 			printf("%s %s (built %s %s)\n",
 				prog_name, RELEASE_VERSION, __DATE__, __TIME__);
-			/* printf("%s\n", REDHAT_COPYRIGHT); */
+			printf("%s\n", REDHAT_COPYRIGHT);
 			exit(EXIT_SUCCESS);
 			break;
 
@@ -256,10 +270,10 @@ static int member_compare(const void *va, const void *vb)
 	return *a - *b;
 }
 
-static int groupd_list(int argc, char **argv, int *total)
+static int groupd_list(int argc, char **argv)
 {
 	group_data_t data[MAX_GROUPS];
-	int i, j, rv, count = 0, level;
+	int i, j, rv, count = 0, level, ret = 0;
 	char *name, *state_header;
 	int type_width = 16;
 	int level_width = 5;
@@ -276,6 +290,18 @@ static int groupd_list(int argc, char **argv, int *total)
 
 		rv = group_get_group(level, name, data);
 		count = 1;
+
+		/* don't output if there's no group at all */
+		if (data[0].id == 0) {
+			fprintf(stderr, "groupd has no information about "
+			        "the specified group\n");
+			return 1;
+		}
+		/* If we wanted a specific group but we are not
+		   joined, print it out - but return failure to
+		   the caller */
+		if (data[0].member != 1)
+			ret = 1;
 	} else
 		rv = group_get_groups(MAX_GROUPS, &count, data);
 
@@ -285,8 +311,6 @@ static int groupd_list(int argc, char **argv, int *total)
 	if (!count)
 		return 0;
 
-	*total = count;
-
 	for (i = 0; i < count; i++) {
 		len = strlen(data[i].name);
 		if (len > max_name)
@@ -299,16 +323,16 @@ static int groupd_list(int argc, char **argv, int *total)
 	else
 		state_header = "state";
 			
-	printf("%-*s %-*s %-*s %-*s %-*s\n",
-		type_width, "type",
-		level_width, "level",
-		name_width, "name",
-		id_width, "id",
-		state_width, state_header);
-
 	qsort(&data, count, sizeof(group_data_t), data_compare);
 
 	for (i = 0; i < count; i++) {
+		if (!i)
+			printf("%-*s %-*s %-*s %-*s %-*s\n",
+			       type_width, "type",
+			       level_width, "level",
+			       name_width, "name",
+			       id_width, "id",
+			       state_width, state_header);
 
 		printf("%-*s %-*d %-*s %0*x %-*s\n",
 			type_width, data[i].client_name,
@@ -328,7 +352,7 @@ static int groupd_list(int argc, char **argv, int *total)
 		}
 		printf("]\n");
 	}
-	return 0;
+	return ret;
 }
 
 static int fenced_node_compare(const void *va, const void *vb)
@@ -339,6 +363,15 @@ static int fenced_node_compare(const void *va, const void *vb)
 	return a->nodeid - b->nodeid;
 }
 
+static void print_header(void)
+{
+	if (print_header_done)
+		return;
+	print_header_done = 1;
+
+	printf("type         level name             id       state\n");
+}
+
 static void fenced_list(void)
 {
 	struct fenced_domain d;
@@ -351,6 +384,8 @@ static void fenced_list(void)
 	if (rv < 0)
 		return;
 
+	print_header();
+
 	printf("fence        0     %-*s %08x %d\n",
 	       16, "default", 0, d.state);
 
@@ -413,6 +448,9 @@ static void dlm_controld_list(void)
 	for (i = 0; i < ls_count; i++) {
 		ls = &lss[i];
 
+		if (!i)
+			print_header();
+
 		printf("dlm          1     %-*s %08x %x\n",
 			16, ls->name, ls->global_id, ls->flags);
 
@@ -476,6 +514,9 @@ static void gfs_controld_list(void)
 	for (i = 0; i < mg_count; i++) {
 		mg = &mgs[i];
 
+		if (!i)
+			print_header();
+
 		printf("gfs          2     %-*s %08x %x\n",
 			16, mg->name, mg->global_id, mg->flags);
 
@@ -567,7 +608,7 @@ static int do_log(char *comment)
 
 int main(int argc, char **argv)
 {
-	int total = 0;
+	int rv, version;
 
 	prog_name = argv[0];
 	decode_arguments(argc, argv);
@@ -575,30 +616,28 @@ int main(int argc, char **argv)
 	switch (operation) {
 	case OP_LIST:
 		if (all_daemons) {
-			if (verbose) {
-				system("fence_tool ls -v");
-				system("dlm_tool ls -v");
-				system("gfs_control ls -v");
+			if (verbose || ls_all_nodes) {
+				system("fence_tool ls -n");
+				system("dlm_tool ls -n");
+				system("gfs_control ls -n");
 			} else {
 				system("fence_tool ls");
 				system("dlm_tool ls");
 				system("gfs_control ls");
 			}
-			break;
+		} else {
+			rv = group_get_version(&version);
+
+			if (version == -EAGAIN) {
+				printf("groupd detecting version...\n");
+			} else if (!rv && version == GROUP_LIBGROUP) {
+				groupd_list(argc, argv);
+			} else {
+				fenced_list();
+				dlm_controld_list();
+				gfs_controld_list();
+			}
 		}
-
-		/* If no groupd or no groups found in groupd, then try
-		   the querying the daemons.  Print any data from the
-		   new daemons in a format similar to the old format. */
-
-		groupd_list(argc, argv, &total);
-		if (total)
-			break;
-
-		printf("type         level name             id       state\n");
-		fenced_list();
-		dlm_controld_list();
-		gfs_controld_list();
 		break;
 
 	case OP_DUMP:
