@@ -6,7 +6,7 @@
 #include <vf.h>
 #include <message.h>
 #include <ccs.h>
-#include <clulog.h>
+#include <logging.h>
 #include <members.h>
 #include <list.h>
 #include <reslist.h>
@@ -107,14 +107,14 @@ count_resource_groups(cluster_member_list_t *ml)
 		res_build_name(rgname, sizeof(rgname), res);
 
 		if (rg_lock(rgname, &lockp) < 0) {
-			clulog(LOG_ERR, "#XX: Unable to obtain cluster "
+			log_printf(LOG_ERR, "#XX: Unable to obtain cluster "
 			       "lock @ %s:%d: %s\n", __FILE__, __LINE__,
 			       strerror(errno));
 			continue;
 		}
 
 		if (get_rg_state(rgname, &st) < 0) {
-			clulog(LOG_ERR, "#34: Cannot get status "
+			log_printf(LOG_ERR, "#34: Cannot get status "
 			       "for service %s\n", rgname);
 			rg_unlock(&lockp);
 			continue;
@@ -432,7 +432,7 @@ check_rdomain_crash(char *svcName)
 		goto out_free;
 
 	if (icount == 0) {
-		clulog(LOG_NOTICE, "Marking %s as stopped: "
+		log_printf(LOG_NOTICE, "Marking %s as stopped: "
 		       "Restricted domain unavailable\n", svcName);
 		rt_enqueue_request(svcName, RG_STOP, NULL, 0, 0,
 				   0, 0);
@@ -491,7 +491,7 @@ consider_start(resource_node_t *node, char *svcName, rg_state_t *svcStatus,
 				     (atoi(val)==0))));
 		if (!autostart) {
 			/*
-			clulog(LOG_DEBUG,
+			log_printf(LOG_DEBUG,
 			       "Skipping RG %s: Autostart disabled\n",
 			       svcName);
 			 */
@@ -500,14 +500,14 @@ consider_start(resource_node_t *node, char *svcName, rg_state_t *svcStatus,
 			   confusion!
 			 */
 			if (rg_lock(svcName, &lockp) < 0) {
-				clulog(LOG_ERR, "#XX: Unable to obtain cluster "
+				log_printf(LOG_ERR, "#XX: Unable to obtain cluster "
 				       "lock @ %s:%d: %s\n", __FILE__, __LINE__,
 				       strerror(errno));
 				return;
 			}
 
 			if (get_rg_state(svcName, svcStatus) != 0) {
-				clulog(LOG_ERR, "#34: Cannot get status "
+				log_printf(LOG_ERR, "#34: Cannot get status "
 				       "for service %s\n", svcName);
 				rg_unlock(&lockp);
 				return;
@@ -528,7 +528,7 @@ consider_start(resource_node_t *node, char *svcName, rg_state_t *svcStatus,
 	/* See if service this one depends on is running.  If not,
            don't start it */
 	if (check_depend(node->rn_resource) == 0) {
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 		       "Skipping RG %s: Dependency missing\n", svcName);
 		return;
 	}
@@ -537,7 +537,7 @@ consider_start(resource_node_t *node, char *svcName, rg_state_t *svcStatus,
 	exclusive = val && ((!strcmp(val, "yes") || (atoi(val)>0)));
 
 	if (exclusive && mp->cn_svccount) {
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 		       "Skipping RG %s: Exclusive and I am running services\n",
 		       svcName);
 		return;
@@ -548,7 +548,7 @@ consider_start(resource_node_t *node, char *svcName, rg_state_t *svcStatus,
 	   service.
 	 */
 	if (mp->cn_svcexcl) {
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 		       "Skipping RG %s: I am running an exclusive service\n",
 		       svcName);
 		return;
@@ -603,7 +603,7 @@ consider_relocate(char *svcName, rg_state_t *svcStatus, uint32_t nodeid,
 		req = RG_MIGRATE;
 	}
 
-	clulog(LOG_NOTICE, "%s %s to better node %s\n",
+	log_printf(LOG_NOTICE, "%s %s to better node %s\n",
 	       req==RG_MIGRATE ? "Migrating":"Relocating",
 	       svcName,
 	       memb_id_to_name(membership, nodeid));
@@ -684,7 +684,7 @@ eval_groups(int local, uint32_t nodeid, int nodeStatus)
 	int ret;
 
 	if (rg_locked()) {
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 			"Resource groups locked; not evaluating\n");
 		return -EAGAIN;
 	}
@@ -705,7 +705,7 @@ eval_groups(int local, uint32_t nodeid, int nodeStatus)
 		 * status.
 		 */
 		if ((ret = rg_lock(svcName, &lockp)) < 0) {
-			clulog(LOG_ERR,
+			log_printf(LOG_ERR,
 			       "#33: Unable to obtain cluster lock: %s\n",
 			       strerror(-ret));
 			pthread_rwlock_unlock(&resource_lock);
@@ -714,7 +714,7 @@ eval_groups(int local, uint32_t nodeid, int nodeStatus)
 		}
 		
 		if (get_rg_state(svcName, &svcStatus) != 0) {
-			clulog(LOG_ERR,
+			log_printf(LOG_ERR,
 			       "#34: Cannot get status for service %s\n",
 			       svcName);
 			rg_unlock(&lockp);
@@ -736,7 +736,7 @@ eval_groups(int local, uint32_t nodeid, int nodeStatus)
 			continue;
 		}
 
-		clulog(LOG_DEBUG, "Evaluating RG %s, state %s, owner "
+		log_printf(LOG_DEBUG, "Evaluating RG %s, state %s, owner "
 		       "%s\n", svcName,
 		       rg_state_str(svcStatus.rs_state),
 		       nodeName);
@@ -771,7 +771,7 @@ eval_groups(int local, uint32_t nodeid, int nodeStatus)
 	pthread_rwlock_unlock(&resource_lock);
 	free_member_list(membership);
 
-	clulog(LOG_DEBUG, "Event (%d:%d:%d) Processed\n", local,
+	log_printf(LOG_DEBUG, "Event (%d:%d:%d) Processed\n", local,
 	       (int)nodeid, nodeStatus);
 
 	return 0;
@@ -795,7 +795,7 @@ group_event(char __attribute__ ((unused)) *rg_name,
 	int depend;
 
 	if (rg_locked()) {
-		clulog(LOG_DEBUG,
+		log_printf(LOG_DEBUG,
 			"Resource groups locked; not evaluating\n");
 		return -EAGAIN;
 	}
@@ -847,7 +847,7 @@ group_event(char __attribute__ ((unused)) *rg_name,
 		    svcStatus.rs_state == RG_STATE_STOPPED &&
 		    state == RG_STATE_STARTED) {
 
-			clulog(LOG_DEBUG, "Evaluating RG %s, state %s, owner "
+			log_printf(LOG_DEBUG, "Evaluating RG %s, state %s, owner "
 			       "%s\n", svcName,
 			       rg_state_str(svcStatus.rs_state),
 			       nodeName);
@@ -863,7 +863,7 @@ group_event(char __attribute__ ((unused)) *rg_name,
 		    svcStatus.rs_state == RG_STATE_STARTED &&
 		    svcStatus.rs_owner == (uint32_t)my_id()) {
 
-			clulog(LOG_WARNING, "Stopping service %s: Dependency missing\n",
+			log_printf(LOG_WARNING, "Stopping service %s: Dependency missing\n",
 			       svcName);
 			rt_enqueue_request(svcName, RG_STOP, NULL, 0, my_id(),
 					   0, 0);
@@ -1007,7 +1007,7 @@ group_migrate(char *groupname, int target)
 	cluster_member_list_t *membership;
 
 	if (target <= 0) {
-		clulog(LOG_WARNING,
+		log_printf(LOG_WARNING,
 		       "Illegal node ID %d during migrate operation\n",
 		       target);
 		return RG_EINVAL;
@@ -1015,7 +1015,7 @@ group_migrate(char *groupname, int target)
 
 	membership = member_list();
 	if (!membership) {
-		clulog(LOG_ERR, "Unable to determine membership during "
+		log_printf(LOG_ERR, "Unable to determine membership during "
 		       "migrate operation\n");
 		return RG_EFAIL;
 	}
@@ -1024,7 +1024,7 @@ group_migrate(char *groupname, int target)
 	
 	tgt_name = memb_id_to_name(membership, target);
 	if (!tgt_name) {
-		clulog(LOG_WARNING, "Node ID %d not in membership during "
+		log_printf(LOG_WARNING, "Node ID %d not in membership during "
 		       "migrate operation\n", target);
 		ret = RG_EINVAL;
 		goto out;
@@ -1032,7 +1032,7 @@ group_migrate(char *groupname, int target)
 
 	res = find_root_by_ref(&_resources, groupname);
 	if (!res) {
-		clulog(LOG_WARNING,
+		log_printf(LOG_WARNING,
 		       "Unable to find '%s' in resource list during"
 		       "migrate operation\n", groupname);
 		goto out;
@@ -1046,20 +1046,20 @@ group_migrate(char *groupname, int target)
 	} while (!list_done(&_tree, tmp));
 
 	if (!rn) {
-		clulog(LOG_WARNING,
+		log_printf(LOG_WARNING,
 		       "Unable to find '%s' it top level of resource "
 		       "tree during migrate operation\n", groupname);
 		goto out;
 	}
 	
-	clulog(LOG_NOTICE, "Migrating %s to %s\n", groupname, tgt_name);
+	log_printf(LOG_NOTICE, "Migrating %s to %s\n", groupname, tgt_name);
 	ret = res_exec(rn, RS_MIGRATE, tgt_name, 0);
 	if (ret == 0) {
-		clulog(LOG_NOTICE,
+		log_printf(LOG_NOTICE,
 		       "Migration of %s to %s completed\n",
 		       groupname, tgt_name);
 	} else {
-		clulog(LOG_ERR, 
+		log_printf(LOG_ERR, 
 		       "Migration of %s to %s failed; return code %d\n",
 		       groupname, tgt_name, ret);
 	}
@@ -1267,7 +1267,7 @@ svc_exists(char *svcname)
 
 
 void
-rg_doall(int request, int block, char *debugfmt)
+rg_doall(int request, int block, char __attribute__ ((unused)) *debugfmt)
 {
 	resource_node_t *curr;
 	rg_state_t svcblk;
@@ -1279,8 +1279,8 @@ rg_doall(int request, int block, char *debugfmt)
 		/* Group name */
 		res_build_name(rg, sizeof(rg), curr->rn_resource);
 
-		if (debugfmt)
-			clulog(LOG_DEBUG, debugfmt, rg);
+		//if (debugfmt)
+			//log_printf(LOG_DEBUG, debugfmt, rg);
 
 		/* Optimization: Don't bother even queueing the request
 		   during the exit case if we don't own it */
@@ -1385,7 +1385,7 @@ do_condstops(void)
 	int need_kill;
 	char rg[64];
 
-	clulog(LOG_INFO, "Stopping changed resources.\n");
+	log_printf(LOG_INFO, "Stopping changed resources.\n");
 
 	pthread_rwlock_rdlock(&resource_lock);
 	list_do(&_tree, curr) {
@@ -1405,14 +1405,14 @@ do_condstops(void)
 		need_kill = 0;
 		if (curr->rn_resource->r_flags & RF_NEEDSTOP) {
 			need_kill = 1;
-			clulog(LOG_DEBUG, "Removing %s\n", rg);
+			log_printf(LOG_DEBUG, "Removing %s\n", rg);
 		}
 
 		if (!curr->rn_child && ((curr->rn_resource->r_rule->rr_flags &
 		    RF_DESTROY) == 0) && group_migratory(rg, 0) &&
 		    need_kill == 1) {
 			/* Do something smart here: flip state? */
-			clulog(LOG_NOTICE,
+			log_printf(LOG_NOTICE,
 			       "%s removed from the config, but I am not stopping it.\n",
 			       rg);
 			if (rg_lock(rg, &lockp) != 0)
@@ -1448,7 +1448,7 @@ do_condstarts(void)
 	int need_init, new_groups = 0, autostart;
 	struct dlm_lksb lockp;
 
-	clulog(LOG_INFO, "Starting changed resources.\n");
+	log_printf(LOG_INFO, "Starting changed resources.\n");
 
 	/* Pass 1: Start any normally changed resources */
 	pthread_rwlock_rdlock(&resource_lock);
@@ -1483,14 +1483,14 @@ do_condstarts(void)
 
 		if (need_init) {
 			++new_groups;
-			clulog(LOG_NOTICE, "Initializing %s\n", rg);
+			log_printf(LOG_NOTICE, "Initializing %s\n", rg);
 		}
 
 		if (!curr->rn_child && ((curr->rn_resource->r_rule->rr_flags &
 		    RF_INIT) == 0) && group_migratory(rg, 0) &&
 		    need_init == 1) {
 			/* Do something smart here? */
-			clulog(LOG_NOTICE,
+			log_printf(LOG_NOTICE,
 			       "%s was added to the config, but I am not initializing it.\n",
 			       rg);
 			continue;
@@ -1614,19 +1614,19 @@ init_resource_groups(int reconfigure, int do_init)
 	char *val;
 
 	if (reconfigure)
-		clulog(LOG_NOTICE, "Reconfiguring\n");
-	clulog(LOG_INFO, "Loading Service Data\n");
-	clulog(LOG_DEBUG, "Loading Resource Rules\n");
+		log_printf(LOG_NOTICE, "Reconfiguring\n");
+	log_printf(LOG_INFO, "Loading Service Data\n");
+	log_printf(LOG_DEBUG, "Loading Resource Rules\n");
 	if (load_resource_rules(RESOURCE_ROOTDIR, &rulelist) != 0) {
 		return -1;
 	}
 	x = 0;
 	list_do(&rulelist, rule) { ++x; } while (!list_done(&rulelist, rule));
-	clulog(LOG_DEBUG, "%d rules loaded\n", x);
+	log_printf(LOG_DEBUG, "%d rules loaded\n", x);
 
        	fd = ccs_lock();
 	if (fd == -1) {
-		clulog(LOG_CRIT, "#5: Couldn't connect to ccsd!\n");
+		log_printf(LOG_CRIT, "#5: Couldn't connect to ccsd!\n");
 		return -1;
 	}
 
@@ -1643,10 +1643,10 @@ init_resource_groups(int reconfigure, int do_init)
 		free(val);
 	}
 
-	clulog(LOG_DEBUG, "Building Resource Trees\n");
+	log_printf(LOG_DEBUG, "Building Resource Trees\n");
 	/* About to update the entire resource tree... */
 	if (load_resources(fd, &reslist, &rulelist) != 0) {
-		clulog(LOG_CRIT, "#6: Error loading services\n");
+		log_printf(LOG_CRIT, "#6: Error loading services\n");
 		destroy_resources(&reslist);
 		destroy_resource_rules(&rulelist);
 		ccs_unlock(fd);
@@ -1654,7 +1654,7 @@ init_resource_groups(int reconfigure, int do_init)
 	}
 
 	if (build_resource_tree(fd, &tree, &rulelist, &reslist) != 0) {
-		clulog(LOG_CRIT, "#7: Error building resource tree\n");
+		log_printf(LOG_CRIT, "#7: Error building resource tree\n");
 		destroy_resource_tree(&tree);
 		destroy_resources(&reslist);
 		destroy_resource_rules(&rulelist);
@@ -1664,13 +1664,13 @@ init_resource_groups(int reconfigure, int do_init)
 
 	x = 0;
 	list_do(&reslist, res) { ++x; } while (!list_done(&reslist, res));
-	clulog(LOG_DEBUG, "%d resources defined\n", x);
+	log_printf(LOG_DEBUG, "%d resources defined\n", x);
 
-	clulog(LOG_DEBUG, "Loading Failover Domains\n");
+	log_printf(LOG_DEBUG, "Loading Failover Domains\n");
 	construct_domains(fd, &domains);
 	x = 0;
 	list_do(&domains, fod) { ++x; } while (!list_done(&domains, fod));
-	clulog(LOG_DEBUG, "%d domains defined\n", x);
+	log_printf(LOG_DEBUG, "%d domains defined\n", x);
 	construct_events(fd, &evt);
 	cnt = 0;
 	if (evt) {
@@ -1687,7 +1687,7 @@ init_resource_groups(int reconfigure, int do_init)
 			cnt += y;
 		}
 	}
-	clulog(LOG_DEBUG, "%d events defined\n", x);
+	log_printf(LOG_DEBUG, "%d events defined\n", x);
 	
 
 	/* Reconfiguration done */
@@ -1725,16 +1725,16 @@ init_resource_groups(int reconfigure, int do_init)
 	if (reconfigure) {
 		/* Switch to read lock and do the up-half of the
 		   reconfig request */
-		clulog(LOG_INFO, "Restarting changed resources.\n");
+		log_printf(LOG_INFO, "Restarting changed resources.\n");
 		do_condstarts();
 	} else {
 		if (do_init) {
 			/* Do initial stop-before-start */
-			clulog(LOG_INFO, "Initializing Services\n");
+			log_printf(LOG_INFO, "Initializing Services\n");
 			rg_doall(RG_INIT, 1, "Initializing %s\n");
-			clulog(LOG_INFO, "Services Initialized\n");
+			log_printf(LOG_INFO, "Services Initialized\n");
 		} else {
-			clulog(LOG_INFO, "Skipping stop-before-start: overridden by administrator\n");
+			log_printf(LOG_INFO, "Skipping stop-before-start: overridden by administrator\n");
 		}
 		rg_set_initialized();
 	}
