@@ -8,7 +8,7 @@
 #include <rg_locks.h>
 #include <fcntl.h>
 #include <resgroup.h>
-#include <clulog.h>
+#include <logging.h>
 #include <members.h>
 #include <msgsimple.h>
 #include <vf.h>
@@ -17,6 +17,7 @@
 #include <malloc.h>
 #include <cman-private.h>
 #include <event.h>
+#include <members.h>
 
 #define L_SHUTDOWN (1<<2)
 #define L_SYS (1<<1)
@@ -31,7 +32,7 @@ void set_transition_throttling(int);
 void node_event(int, int, int, int);
 void node_event_q(int, int, int, int);
 int daemon_init(char *);
-int init_resource_groups(int);
+int init_resource_groups(int, int);
 void kill_resource_groups(void);
 void set_my_id(int);
 void flag_shutdown(int sig);
@@ -42,11 +43,15 @@ int svc_exists(char *);
 int watchdog_init(void);
 int32_t master_event_callback(char *key, uint64_t viewno, void *data, uint32_t datalen);
 
+int node_has_fencing(int nodeid);
+int fence_domain_joined(void);
+
 int shutdown_pending = 0, running = 1, need_reconfigure = 0;
 char debug = 0; /* XXX* */
 static int signalled = 0;
 static uint8_t ALIGNED port = RG_PORT;
 static char *rgmanager_lsname = "rgmanager"; /* XXX default */
+static int status_poll_interval = DEFAULT_CHECK_INTERVAL;
 
 int next_node_id(cluster_member_list_t *membership, int me);
 void malloc_dump_table(FILE *, size_t, size_t);
@@ -133,16 +138,16 @@ membership_update(void)
 		if (!rg_quorate())
 			return -1;
 
-		clulog(LOG_EMERG, "#1: Quorum Dissolved\n");
+		log_printf(LOG_EMERG, "#1: Quorum Dissolved\n");
 		rg_set_inquorate();
 		member_list_update(NULL);/* Clear member list */
 		rg_lockall(L_SYS);
 		rg_doall(RG_INIT, 1, "Emergency stop of %s\n");
 #ifndef USE_OPENAIS
-		clulog(LOG_DEBUG, "Invalidating local VF cache\n");
+		log_printf(LOG_DEBUG, "Invalidating local VF cache\n");
 		vf_invalidate();
 #endif
-		clulog(LOG_DEBUG, "Flushing resource group cache\n");
+		log_printf(LOG_DEBUG, "Flushing resource group cache\n");
 		kill_resource_groups();
 		rg_set_uninitialized();
 		return -1;
@@ -151,7 +156,7 @@ membership_update(void)
 		rg_set_quorate();
 		rg_unlockall(L_SYS);
 		rg_unlockall(L_USER);
-		clulog(LOG_NOTICE, "Quorum Regained\n");
+		log_printf(LOG_NOTICE, "Quorum Regained\n");
 	}
 
 	old_membership = member_list();
@@ -185,7 +190,7 @@ membership_update(void)
 					port);
 
 			if (quorate == 0) {
-				clulog(LOG_DEBUG, "Node %d is not listening\n",
+				log_printf(LOG_DEBUG, "Node %d is not listening\n",
 					new_ml->cml_members[x].cn_nodeid);
 				new_ml->cml_members[x].cn_member = 0;
 				break;
@@ -219,7 +224,7 @@ membership_update(void)
 	me = memb_online(node_delta, my_id());
 	if (me) {
 		/* Should not happen */
-		clulog(LOG_INFO, "State change: LOCAL OFFLINE\n");
+		log_printf(LOG_INFO, "State change: LOCAL OFFLINE\n");
 		if (node_delta)
 			free_member_list(node_delta);
 		node_event(1, my_id(), 0, 0);
@@ -228,7 +233,7 @@ membership_update(void)
 
 	for (x=0; node_delta && x < node_delta->cml_count; x++) {
 
-		clulog(LOG_INFO, "State change: %s DOWN\n",
+		log_printf(LOG_INFO, "State change: %s DOWN\n",
 		       node_delta->cml_members[x].cn_name);
 		/* Don't bother evaluating anything resource groups are
 		   locked.  This is just a performance thing */
@@ -236,7 +241,7 @@ membership_update(void)
 			node_event_q(0, node_delta->cml_members[x].cn_nodeid,
 				     0, 0);
 		} else {
-			clulog(LOG_DEBUG, "Not taking action - services"
+			log_printf(LOG_DEBUG, "Not taking action - services"
 			       " locked\n");
 		}
 	}
@@ -250,7 +255,7 @@ membership_update(void)
 
 	me = memb_online(node_delta, my_id());
 	if (me) {
-		clulog(LOG_INFO, "State change: Local UP\n");
+		log_printf(LOG_INFO, "State change: Local UP\n");
 		node_event_q(1, my_id(), 1, 1);
 	}
 
@@ -262,7 +267,7 @@ membership_update(void)
 		if (node_delta->cml_members[x].cn_nodeid == my_id())
 			continue;
 
-		clulog(LOG_INFO, "State change: %s UP\n",
+		log_printf(LOG_INFO, "State change: %s UP\n",
 		       node_delta->cml_members[x].cn_name);
 		node_event_q(0, node_delta->cml_members[x].cn_nodeid, 1, 1);
 	}
@@ -285,7 +290,7 @@ lock_commit_cb(char __attribute__ ((unused)) *key,
 	char lockstate;
 
 	if (datalen != 1) {
-		clulog(LOG_WARNING, "%s: invalid data length!\n", __FUNCTION__);
+		log_printf(LOG_WARNING, "%s: invalid data length!\n", __FUNCTION__);
 		free(data);
 		return 0;
 	}
@@ -296,18 +301,18 @@ lock_commit_cb(char __attribute__ ((unused)) *key,
 	if (lockstate == 0) {
 		rg_unlockall(L_USER); /* Doing this multiple times
 					 has no effect */
-		clulog(LOG_NOTICE, "Resource Groups Unlocked\n");
+		log_printf(LOG_NOTICE, "Resource Groups Unlocked\n");
 		return 0;
 	}
 
 	if (lockstate == 1) {
 		rg_lockall(L_USER); /* Doing this multiple times
 				       has no effect */
-		clulog(LOG_NOTICE, "Resource Groups Locked\n");
+		log_printf(LOG_NOTICE, "Resource Groups Locked\n");
 		return 0;
 	}
 
-	clulog(LOG_DEBUG, "Invalid lock state in callback: %d\n", lockstate);
+	log_printf(LOG_DEBUG, "Invalid lock state in callback: %d\n", lockstate);
 	return 0;
 }
 
@@ -379,7 +384,7 @@ do_lockreq(msgctx_t *ctx, int req)
 
 #ifdef OPENAIS
 	ret = ds_write("rg_lockdown", &state, 1);
-	clulog(LOG_INFO, "FIXME: send RG_LOCK update to all!\n");
+	log_printf(LOG_INFO, "FIXME: send RG_LOCK update to all!\n");
 #else
 	ret = vf_write(m, VFF_IGN_CONN_ERRORS, "rg_lockdown", &state, 1);
 	free_member_list(m);
@@ -417,7 +422,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 	/* Peek-a-boo */
 	sz = msg_receive(ctx, msg_hdr, sizeof(msgbuf), 1);
 	if (sz < (int)sizeof (generic_msg_hdr)) {
-		clulog(LOG_ERR,
+		log_printf(LOG_ERR,
 		       "#37: Error receiving header from %d sz=%d CTX %p\n",
 		       nodeid, sz, ctx);
 		goto out;
@@ -439,27 +444,27 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 	/* Decode the header */
 	swab_generic_msg_hdr(msg_hdr);
 	if ((msg_hdr->gh_magic != GENERIC_HDR_MAGIC)) {
-		clulog(LOG_ERR,
+		log_printf(LOG_ERR,
 		       "#38: Invalid magic: Wanted 0x%08x, got 0x%08x\n",
 		       GENERIC_HDR_MAGIC, msg_hdr->gh_magic);
 		goto out;
 	}
 
 	if ((int)msg_hdr->gh_length != sz) {
-		clulog(LOG_ERR, "#XX: Read size mismatch: %d %d\n",
+		log_printf(LOG_ERR, "#XX: Read size mismatch: %d %d\n",
 		       ret, msg_hdr->gh_length);
 		goto out;
 	}
 
 	switch (msg_hdr->gh_command) {
 	case RG_STATUS:
-		//clulog(LOG_DEBUG, "Sending service states to CTX%p\n",ctx);
+		//log_printf(LOG_DEBUG, "Sending service states to CTX%p\n",ctx);
 		if (send_rg_states(ctx, msg_hdr->gh_arg1) == 0)
 			need_close = 0;
 		break;
 
 	case RG_STATUS_NODE:
-		//clulog(LOG_DEBUG, "Sending node states to CTX%p\n",ctx);
+		//log_printf(LOG_DEBUG, "Sending node states to CTX%p\n",ctx);
 		send_node_states(ctx);
 		break;
 
@@ -479,7 +484,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 	case RG_ACTION_REQUEST:
 
 		if (sz < (int)sizeof(msg_sm)) {
-			clulog(LOG_ERR,
+			log_printf(LOG_ERR,
 			       "#39: Error receiving entire request (%d/%d)\n",
 			       ret, (int)sizeof(msg_sm));
 			ret = -1;
@@ -498,7 +503,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 
 			if (msg_send(ctx, msg_sm, sizeof (SmMessageSt)) <
 		    	    (int)sizeof (SmMessageSt))
-				clulog(LOG_ERR, "#40: Error replying to "
+				log_printf(LOG_ERR, "#40: Error replying to "
 				       "action request.\n");
 			ret = -1;
 			goto out;
@@ -538,7 +543,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 	case RG_EVENT:
 		/* Service event.  Run a dependency check */
 		if (sz < (int)sizeof(msg_sm)) {
-			clulog(LOG_ERR,
+			log_printf(LOG_ERR,
 			       "#39: Error receiving entire request (%d/%d)\n",
 			       ret, (int)sizeof(msg_sm));
 			ret = -1;
@@ -561,7 +566,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 		if (!member_online(msg_hdr->gh_arg1))
 			break;
 
-		clulog(LOG_NOTICE, "Member %d shutting down\n",
+		log_printf(LOG_NOTICE, "Member %d shutting down\n",
 		       msg_hdr->gh_arg1);
 	       	member_set_state(msg_hdr->gh_arg1, 0);
 		node_event_q(0, msg_hdr->gh_arg1, 0, 1);
@@ -575,7 +580,7 @@ dispatch_msg(msgctx_t *ctx, int nodeid, int need_close)
 		break;
 
 	default:
-		clulog(LOG_DEBUG, "unhandled message request %d\n",
+		log_printf(LOG_DEBUG, "unhandled message request %d\n",
 		       msg_hdr->gh_command);
 		break;
 	}
@@ -605,18 +610,18 @@ handle_cluster_event(msgctx_t *ctx)
 	switch(ret) {
 	case M_PORTOPENED:
 		msg_receive(ctx, NULL, 0, 0);
-		clulog(LOG_DEBUG, "Event: Port Opened\n");
+		log_printf(LOG_DEBUG, "Event: Port Opened\n");
 		membership_update();
 		break;
 	case M_PORTCLOSED:
 		/* Might want to handle powerclosed like membership change */
 		msg_receive(ctx, NULL, 0, 0);
-		clulog(LOG_DEBUG, "Event: Port Closed\n");
+		log_printf(LOG_DEBUG, "Event: Port Closed\n");
 		membership_update();
 		break;
 	case M_NONE:
 		msg_receive(ctx, NULL, 0, 0);
-		clulog(LOG_DEBUG, "NULL cluster message\n");
+		log_printf(LOG_DEBUG, "NULL cluster message\n");
 		break;
 	case M_OPEN:
 		newctx = msg_new_ctx();
@@ -637,12 +642,12 @@ handle_cluster_event(msgctx_t *ctx)
 		
 	case M_OPEN_ACK:
 	case M_CLOSE:
-		clulog(LOG_DEBUG, "I should NOT get here: %d\n",
+		log_printf(LOG_DEBUG, "I should NOT get here: %d\n",
 		       ret);
 		break;
 	case M_STATECHANGE:
 		msg_receive(ctx, NULL, 0, 0);
-		clulog(LOG_DEBUG, "Membership Change Event\n");
+		log_printf(LOG_DEBUG, "Membership Change Event\n");
 		if (running) {
 			rg_unlockall(L_SYS);
 			membership_update();
@@ -653,7 +658,7 @@ handle_cluster_event(msgctx_t *ctx)
 	case 999:
 	case M_TRY_SHUTDOWN:
 		msg_receive(ctx, NULL, 0, 0);
-		clulog(LOG_WARNING, "#67: Shutting down uncleanly\n");
+		log_printf(LOG_WARNING, "#67: Shutting down uncleanly\n");
 		rg_set_inquorate();
 		rg_doall(RG_INIT, 1, "Emergency stop of %s");
 		rg_set_uninitialized();
@@ -698,7 +703,7 @@ event_loop(msgctx_t *localctx, msgctx_t *clusterctx)
 	struct timeval tv;
 	int nodeid;
 
-	tv.tv_sec = 10;
+	tv.tv_sec = status_poll_interval;
 	tv.tv_usec = 0;
 
 	if (signalled) {
@@ -834,16 +839,7 @@ configure_rgmanager(int ccsfd, int dbg)
 			return -1;
 	}
 
-	if (ccs_get(ccsfd, "/cluster/rm/@log_facility", &v) == 0) {
-		clu_set_facility(v);
-		free(v);
-	}
-
-	if (ccs_get(ccsfd, "/cluster/rm/@log_level", &v) == 0) {
-		if (!dbg)
-			clu_set_loglevel(atoi(v));
-		free(v);
-	}
+	setup_logging(ccsfd);
 
 	if (ccs_get(ccsfd, "/cluster/rm/@transition_throttling", &v) == 0) {
 		set_transition_throttling(atoi(v));
@@ -853,11 +849,27 @@ configure_rgmanager(int ccsfd, int dbg)
 	if (ccs_get(ccsfd, "/cluster/rm/@central_processing", &v) == 0) {
 		set_central_events(atoi(v));
 		if (atoi(v))
-			clulog(LOG_NOTICE,
+			log_printf(LOG_NOTICE,
 			       "Centralized Event Processing enabled\n");
 		free(v);
 	}
 
+	if (ccs_get(ccsfd, "/cluster/rm/@status_poll_interval", &v) == 0) {
+		status_poll_interval = atoi(v);
+		if (status_poll_interval >= 1) {
+			log_printf(LOG_NOTICE,
+			       "Status Polling Interval set to %d\n",
+			       status_poll_interval);
+		} else {
+			log_printf(LOG_WARNING, "Ignoring illegal "
+			       "status_poll_interval of %s\n", v);
+			status_poll_interval = 10;
+		}
+		
+		free(v);
+	}
+
+
 	if (internal)
 		ccs_disconnect(ccsfd);
 
@@ -873,7 +885,7 @@ clu_initialize(cman_handle_t *ch)
 
 	*ch = cman_init(NULL);
 	if (!(*ch)) {
-		clulog(LOG_NOTICE, "Waiting for CMAN to start\n");
+		log_printf(LOG_NOTICE, "Waiting for CMAN to start\n");
 
 		while (!(*ch = cman_init(NULL))) {
 			sleep(1);
@@ -887,12 +899,30 @@ clu_initialize(cman_handle_t *ch)
 		   and log in -- this will cause the plugin to not select any
 		   node group (if any exist).
 		 */
-		clulog(LOG_NOTICE, "Waiting for quorum to form\n");
+		log_printf(LOG_NOTICE, "Waiting for quorum to form\n");
 
 		while (cman_is_quorate(*ch) == 0) {
 			sleep(1);
 		}
-		clulog(LOG_NOTICE, "Quorum formed, starting\n");
+		log_printf(LOG_NOTICE, "Quorum formed\n");
+	}
+
+}
+
+
+void
+wait_for_fencing(void)
+{
+        if (node_has_fencing(my_id()) && !fence_domain_joined()) {
+		log_printf(LOG_INFO, "Waiting for fence domain join operation "
+		       "to complete\n");
+
+		while (fence_domain_joined() == 0)
+			sleep(1);
+		log_printf(LOG_INFO, "Fence domain joined\n");
+	} else {
+		log_printf(LOG_DEBUG, "Fence domain already joined "
+		       "or no fencing configured\n");
 	}
 }
 
@@ -924,7 +954,7 @@ void dump_thread_states(FILE *);
 int
 main(int argc, char **argv)
 {
-	int rv;
+	int rv, do_init = 1;
 	char foreground = 0, wd = 1;
 	cman_node_t me;
 	msgctx_t *cluster_ctx;
@@ -932,7 +962,7 @@ main(int argc, char **argv)
 	pthread_t th;
 	cman_handle_t clu = NULL;
 
-	while ((rv = getopt(argc, argv, "wfd")) != EOF) {
+	while ((rv = getopt(argc, argv, "wfdN")) != EOF) {
 		switch (rv) {
 		case 'w':
 			wd = 0;
@@ -940,6 +970,9 @@ main(int argc, char **argv)
 		case 'd':
 			debug = 1;
 			break;
+		case 'N':
+			do_init = 0;
+			break;
 		case 'f':
 			foreground = 1;
 			break;
@@ -952,15 +985,17 @@ main(int argc, char **argv)
 	/*
 	   Set up logging / foreground mode, etc.
 	 */
+#if 0
 	if (debug)
 		clu_set_loglevel(LOG_DEBUG);
 	if (foreground)
 		clu_log_console(1);
+#endif
 
 	if (!foreground && (geteuid() == 0)) {
 		daemon_init(argv[0]);
 		if (wd && !debug && !watchdog_init())
-			clulog(LOG_NOTICE, "Failed to start watchdog\n");
+			log_printf(LOG_NOTICE, "Failed to start watchdog\n");
 	}
 
 	setup_signal(SIGINT, flag_shutdown);
@@ -975,6 +1010,7 @@ main(int argc, char **argv)
 		unblock_signal(SIGSEGV);
 	}
 
+	init_logging();
 	clu_initialize(&clu);
 	if (cman_init_subsys(clu) < 0) {
 		perror("cman_init_subsys");
@@ -996,29 +1032,31 @@ main(int argc, char **argv)
 	}
 	set_my_id(me.cn_nodeid);
 
-	clulog(LOG_INFO, "I am node #%d\n", my_id());
+	log_printf(LOG_INFO, "I am node #%d\n", my_id());
+
+	wait_for_fencing();
 
 	/*
 	   We know we're quorate.  At this point, we need to
 	   read the resource group trees from ccsd.
 	 */
 	configure_rgmanager(-1, debug);
-	clulog(LOG_NOTICE, "Resource Group Manager Starting\n");
+	log_printf(LOG_NOTICE, "Resource Group Manager Starting\n");
 
-	if (init_resource_groups(0) != 0) {
-		clulog(LOG_CRIT, "#8: Couldn't initialize services\n");
+	if (init_resource_groups(0, do_init) != 0) {
+		log_printf(LOG_CRIT, "#8: Couldn't initialize services\n");
 		return -1;
 	}
 
 	if (msg_listen(MSG_SOCKET, RGMGR_SOCK, me.cn_nodeid, &local_ctx) < 0) {
-		clulog(LOG_CRIT,
+		log_printf(LOG_CRIT,
 		       "#10: Couldn't set up cluster message system: %s\n",
 		       strerror(errno));
 		return -1;
 	}
 
 	if (msg_listen(MSG_CLUSTER, &port, me.cn_nodeid, &cluster_ctx) < 0) {
-		clulog(LOG_CRIT,
+		log_printf(LOG_CRIT,
 		       "#10b: Couldn't set up cluster message system: %s\n",
 		       strerror(errno));
 		return -1;
@@ -1036,14 +1074,14 @@ main(int argc, char **argv)
 	 */
 #ifdef OPENAIS
 	if (ds_init() < 0) {
-		clulog(LOG_CRIT, "#11b: Couldn't initialize SAI AIS CKPT\n");
+		log_printf(LOG_CRIT, "#11b: Couldn't initialize SAI AIS CKPT\n");
 		return -1;
 	}
 
 	ds_key_init("rg_lockdown", 32, 10);
 #else
 	if (vf_init(me.cn_nodeid, port, NULL, NULL) != 0) {
-		clulog(LOG_CRIT, "#11: Couldn't set up VF listen socket\n");
+		log_printf(LOG_CRIT, "#11: Couldn't set up VF listen socket\n");
 		return -1;
 	}
 
@@ -1062,17 +1100,18 @@ main(int argc, char **argv)
 			   be ignored here */
 			msg_close(local_ctx);
 			++shutdown_pending;
-			clulog(LOG_NOTICE, "Shutting down\n");
+			log_printf(LOG_NOTICE, "Shutting down\n");
 			pthread_create(&th, NULL, shutdown_thread, NULL);
 		}
 	}
 
 	if (rg_initialized())
 		cleanup(cluster_ctx);
-	clulog(LOG_NOTICE, "Shutdown complete, exiting\n");
+	log_printf(LOG_NOTICE, "Shutdown complete, exiting\n");
 	clu_lock_finished(rgmanager_lsname);
 	cman_finish(clu);
 	
+	close_logging();
 	/*malloc_dump_table(); */ /* Only works if alloc.c us used */
 	/*malloc_stats();*/
 
